import { ACTOR_JOB_STATUSES } from '@apify/consts';
import { Args } from '@oclif/core';
import { ApifyCommand } from '../../lib/apify_command.js';
import { confirmAction } from '../../lib/commands/confirm.js';
import { error, info, success } from '../../lib/outputs.js';
import { getLoggedClientOrThrow } from '../../lib/utils.js';
const deletableStatuses = [
    ACTOR_JOB_STATUSES.SUCCEEDED,
    ACTOR_JOB_STATUSES.FAILED,
    ACTOR_JOB_STATUSES.ABORTED,
    ACTOR_JOB_STATUSES.TIMED_OUT,
];
export class RunsRmCommand extends ApifyCommand {
    async run() {
        const { runId } = this.args;
        const apifyClient = await getLoggedClientOrThrow();
        const run = await apifyClient.run(runId).get();
        if (!run) {
            error({ message: `Run with ID "${runId}" was not found on your account.` });
            return;
        }
        if (!deletableStatuses.includes(run.status)) {
            error({
                message: `Run with ID "${runId}" cannot be deleted, as it is still running or in the process of aborting.`,
            });
            return;
        }
        const confirmedDelete = await confirmAction({
            type: 'Actor Run',
            failureMessage: `Your provided value does not match the run ID.`,
        });
        if (!confirmedDelete) {
            info({
                message: `Deletion of run "${runId}" was canceled.`,
            });
            return;
        }
        try {
            await apifyClient.run(runId).delete();
            success({
                message: `Run with ID "${runId}" was deleted.`,
            });
        }
        catch (err) {
            const casted = err;
            error({ message: `Failed to delete run "${runId}".\n  ${casted.message || casted}` });
        }
    }
}
Object.defineProperty(RunsRmCommand, "description", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: 'Deletes an Actor Run.'
});
Object.defineProperty(RunsRmCommand, "args", {
    enumerable: true,
    configurable: true,
    writable: true,
    value: {
        runId: Args.string({
            description: 'The run ID to delete.',
            required: true,
        }),
    }
});
//# sourceMappingURL=rm.js.map