export interface ResponsiveTableOptions<AllColumns extends string, MandatoryColumns extends NoInfer<AllColumns> = AllColumns> {
    /**
     * Represents all the columns the that this table should show, and their order
     */
    allColumns: AllColumns[];
    /**
     * Represents the columns that are mandatory for the user to see, even if the terminal size is less than adequate (<100).
     * Make sure this field includes columns that provide enough context AND that will fit in an 80-column terminal.
     */
    mandatoryColumns: MandatoryColumns[];
    /**
     * By default, all columns are left-aligned. You can specify columns that should be aligned in the middle or right
     */
    columnAlignments?: Partial<Record<AllColumns, 'left' | 'center' | 'right'>>;
}
export declare class ResponsiveTable<AllColumns extends string, MandatoryColumns extends NoInfer<AllColumns> = AllColumns> {
    private options;
    private rows;
    constructor(options: ResponsiveTableOptions<AllColumns, MandatoryColumns>);
    pushRow(item: Record<AllColumns, string>): void;
    render(compact?: boolean): string;
}
//# sourceMappingURL=responsive-table.d.ts.map