import Table from 'cli-table3';
const compactModeChars = {
    'mid': '',
    'left-mid': '',
    'mid-mid': '',
    'right-mid': '',
    middle: ' ',
    'top-mid': '─',
    'bottom-mid': '─',
};
function generateHeaderColors(length) {
    return Array.from({ length }, () => 'cyan');
}
const terminalColumns = process.stdout.columns ?? 100;
export class ResponsiveTable {
    constructor(options) {
        Object.defineProperty(this, "options", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "rows", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: []
        });
        this.options = options;
    }
    pushRow(item) {
        this.rows.push(item);
    }
    render(compact = false) {
        const head = terminalColumns < 100 ? this.options.mandatoryColumns : this.options.allColumns;
        const headColors = generateHeaderColors(head.length);
        const chars = compact ? compactModeChars : undefined;
        const colAligns = [];
        for (const column of head) {
            colAligns.push(this.options.columnAlignments?.[column] || 'left');
        }
        const table = new Table({
            head,
            style: {
                head: headColors,
                compact,
            },
            colAligns,
            chars,
        });
        for (const rowData of this.rows) {
            const row = head.map((col) => rowData[col]);
            table.push(row);
        }
        return table.toString();
    }
}
//# sourceMappingURL=responsive-table.js.map